@@ -30,15 +30,14 @@ swf_object_open(void) {
 
 void
 swf_object_close(swf_object_t *swf) {
-    swf_tag_t *tag, *next_tag;
-    if (! swf) {
-        return ;
+    if (swf) {
+        swf_tag_t *tag, *next_tag;
+        for (tag=swf->tag ; tag ; tag=next_tag) {
+            next_tag = tag->next;
+            swf_tag_destroy(tag);
+        }
+        free(swf);
     }
-    for (tag=swf->tag ; tag ; tag=next_tag) {
-        next_tag = tag->next;
-        swf_tag_destroy(tag);
-    }
-    free(swf);
     malloc_debug_end(); /* DEBUG XXX */
     return ;
 }
@@ -647,10 +646,18 @@ swf_object_insert_action_setvariables(swf_object_t *swf,
         return 1; // NG
     }
     for (tag=swf->tag ; tag ; tag=tag->next) {
-        if ((tag->tag != 69) && (tag->tag != 9)) { // FileAttributs or SetBackgroundColor
+        switch (tag->tag) {
+        case 69: // FileAttributs
+        case  9:  // SetBackgroundColor
+        case 24: // Protect
+            break;
+        default:
             next_tag = tag;
             break;
         }
+        if (next_tag) { // found
+            break;
+        }
         prev_tag = tag;
     }
     if (next_tag == NULL) {
